@@ -5,7 +5,7 @@
  *
  * \brief Class def header for a class BatchData
  *
- * @author kazuhiro
+ * @author kazuhiro cadams
  */
 
 /** \addtogroup ThreadIO
@@ -17,7 +17,7 @@
 #include <iostream>
 #include <vector>
 #include "QueueIOTypes.h"
-#include "larcv3/core/pyutil/PyUtils.h"
+#include "larcv3/core/dataformat/DataFormatTypes.h"
 
 #ifdef LARCV_INTERNAL
 #include <pybind11/pybind11.h>
@@ -27,8 +27,7 @@
 namespace larcv3 {
   /**
      \class BatchData
-     User defined class BatchData ... these comments are used to generate
-     doxygen documentation!
+
   */
   template <class T>
   class BatchData {
@@ -44,6 +43,7 @@ namespace larcv3 {
     /// Default destructor
     ~BatchData() {}
 
+    /// Read access to the data:
     const std::vector<T>& data() const;
 
     // Writeable access to data:
